@@ -399,7 +399,7 @@ class RundeckJobs(object):
         os.environ["TF_REGISTRY_DISCOVERY_RETRY"] = "10"
         os.environ["TF_REGISTRY_CLIENT_TIMEOUT"] = "60"
         os.environ["TF_IN_AUTOMATION"] = "true"
-        os.environ["TF_PLUGIN_CACHE_DIR="] = "~/.terraform.d/plugin-cache"
+        os.environ["TF_PLUGIN_CACHE_DIR"] = "$HOME/.terraform.d/plugin-cache"
         os.environ["TF_DATA_DIR"] = config_dir_location
 
         # shutil.copytree(f"{terraform_code_dir}/", f"{config_dir_location}/")
