@@ -1,7 +1,6 @@
 import os
 
 import typer
-from loguru import logger
 
 from helpo.rundeckjobs import RundeckJobs
 
@@ -44,7 +43,7 @@ def terraform_cloud_workspace(
         vcs_repo_oauth_token_id: str = os.environ.get(
             'RD_OPTION_VCS_REPO_OAUTH_TOKEN_ID'),
         tag_names: str = os.environ.get('RD_OPTION_TAG_NAMES'),
-        terraform_code_dir: str = "/home/rundeck/terraform/rootmodule/terraform_cloud_workspace",
+        terraform_code_dir: str = "/home/rundeck/codebase/terraform/rootmodule/terraform_cloud_workspace",
 ):
     rundeck_jobs = RundeckJobs()
     rundeck_jobs.terraform_cloud_workspace(
@@ -96,7 +95,7 @@ def hcloud_web_solutions(
         jira_issue_key: str = os.environ.get("RD_OPTION_JIRA_ISSUE_KEY"),
         terraform_cloud_token: str = os.environ.get(
             "RD_OPTION_TERRAFORM_CLOUD_TOKEN"),
-        terraform_code_dir: str = f"/home/rundeck/terraform/rootmodule/hcloud_web_solutions"
+        terraform_code_dir: str = f"/home/rundeck/codebase/terraform/rootmodule/hcloud_web_solutions"
 
 ):
     rundeck_jobs = RundeckJobs()
@@ -110,5 +109,36 @@ def hcloud_web_solutions(
                                       jira_issue_key, terraform_cloud_token, terraform_code_dir)
 
 
+@app.command()
+def nextjs_build(
+        pg_user: str = os.environ.get(
+            'RD_OPTION_TERRAFORM_PG_BACKEND_USER'),
+        pg_password: str = os.environ.get(
+            'RD_OPTION_TERRAFORM_PG_BACKEND_PASSWORD'),
+        pg_ip: str = os.environ.get('RD_OPTION_TERRAFORM_PG_BACKEND_IP'),
+        pg_port: str = os.environ.get(
+            'RD_OPTION_TERRAFORM_PG_BACKEND_PORT'),
+        pg_db: str = os.environ.get('RD_OPTION_TERRAFORM_PG_BACKEND_DB'),
+        fqdn: str = os.environ.get("RD_OPTION_FQDN"),
+        organization: str = os.environ.get('RD_OPTION_ORGANIZATION'),
+        deployment_action: str = os.environ.get(
+            'RD_OPTION_DEPLOYMENT_ACTION'),
+        git_domain: str = os.environ.get('RD_OPTION_GIT_DOMAIN'),
+        git_reponame: str = os.environ.get('RD_OPTION_GIT_REPONAME'),
+        git_branch: str = os.environ.get('RD_OPTION_GIT_BRANCH'),
+        workspace_name: str = os.environ.get('RD_OPTION_WORKSPACE_NAME'),
+        app_code_dir: str = os.environ.get('RD_OPTION_APP_CODE_DIR'),
+        vault_login_username: str = os.environ.get(
+            'RD_OPTION_VAULT_LOGIN_USERNAME'),
+        vault_login_password: str = os.environ.get(
+            'RD_OPTION_VAULT_LOGIN_PASSWORD'),
+        terraform_code_dir: str = f"{os.path.expanduser('~')}/codebase/terraform/rootmodule/nextjs_build",
+):
+    rundeck_jobs = RundeckJobs()
+    rundeck_jobs.nextjs_build(pg_user, pg_password, pg_ip, pg_port, pg_db, fqdn, organization, deployment_action,
+                              git_domain, git_reponame, git_branch, workspace_name, app_code_dir, vault_login_username,
+                              vault_login_password, terraform_code_dir)
+
+
 if __name__ == "__main__":
     app()
